% Example6_2.m
% Solution to Example 6-2. This program calculates and plots
% the concentration profiles of a gas A diffusing in liquid B
% by solving the unsteady-state mole balance equation using
% the function PARABOLIC1D.M.

clear
redo = 1;
clc
disp(' Solution of parabolic partial differential equation.')
while redo
   disp(' ')
   h = input(' Depth of the container (m) = ');
   tmax = input(' Maximum time (s) = ');
   p = input(' Number of divisions in z-direction = ');
   q = input(' Number of divisions in t-direction = ');
   Dab = input(' Diffusion coefficient of A in B = ');
   disp(' ')
   disp(' 1 - No reaction between A and B')
   disp(' 2 - A reacts with B')
   react = input(' Enter your choice : ') - 1;
   if react
      disp(' ')
      k = input(' Rate constant = ');
      f = input(' Name of the file containing the rate law = ');
   end
   disp(' ')
   disp(' Boundary conditions:')
   disp(' ')
   ca0 = input(' Concentration of A at interface (mol/m3) = ');
   bc(1,1) = 1;
   bc(1,2) = ca0;
   disp(' ')
   disp(' Condition at Bottom of the container:')
   disp('   1 - Dirichlet')
   disp('   2 - Neumann')
   disp('   3 - Robbins')
   bc(2,1) = input(' Enter your choice : ');
   if bc(2,1) < 3
      bc(2,2) = input(' Value = ');
   else
      disp(' u'' = (beta) + (gamma)*u')
      bc(2,2) = input(' Constant    (beta)  = ');
      bc(2,3) = input(' Coefficient (gamma) = ');
   end
   u0 = [ca0; zeros(p,1)];
   % Calculating concentration profile
   if react
      [z,t,ca] = parabolic1D(p,q,h/p,tmax/q,Dab,u0,bc,f,k);
   else
      [z,t,ca] = parabolic1D(p,q,h/p,tmax/q,Dab,u0,bc);
   end
   % Calculating the flux of A
   Naz = -Dab*diff(ca(1:2,:))/diff(z(1:2));
   % Plotting concentration profile
   tt=[];	% Making time matrix from time vector
   for kk = 1 : p+1
      tt = [tt; t];
   end
   zz = [];	% Making height matrix from height vector
   for kk = 1 : q+1
      zz = [zz z'];
   end
   figure(1)
   [a,b]=contour(zz*1000,ca/ca0,tt/3600/24,[0:5:tmax/3600/24]);
   clabel(a,b,[10:10:tmax/3600/24])
   xlabel('z (mm)')
   ylabel('C_A/C_A_0')
   title('t (days)')
   % Plotting the unsteady-state flux
   figure(2)
   loglog(t/3600/24,Naz*3600*24)
   xlabel('t (days)')
   ylabel(' N_{Az} (mol/m^2.day)')
   disp(' ')
   redo = input(' Repeat calculations (0/1) ? ');
   clc
end
